function tfplist = setupTFplan();
%% ===========================================================================
%setupTFplan - Sets up the experiment description structure for
% a certain FSAN duplex experiment.
%
% Returns:      tfplist		A list of structures describing time and
%                               frequency plans
%
% Example(s):
%    tfplist = setupTFplan(); generates a list of known time and
%    frequency plans.
%
% Algorithmic details:
%
% Reference:
%    FSAN duplex simulation memo, Telia 1998
%  Mask definitions:
%    Hamband:
%    HDSL: ETSI ETR 152
%    IDSN: (living list r8) at ETSI Hilversum June/98
%    ADSL: ANSI ADSL DMT standard Issue 2 draft, (G.lite) proposal
%    FSAN masks: ETSI 985t14a0
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 1998,99 by Telia Research AB, Lulea, Sweden; All rights reserved. 
% Project       : FSAN duplex model
% Author(s)     : Tomas Nordstrom (Tomas.B.Nordstrom@Telia.se)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: setupTFplan.m,v 1.5 1999/03/31 13:31:51 dab Exp $
%% ===========================================================================
% Change History
%      1998-10-19 (ToNo) Created
%      1998-11-13 (ToNo) Splitted setup into three parts param,tfplan,tt
%      1998-12-17 (DaB)  Rewritten HAM bands PSD mask
%      1998-12-21 (ToNo) Moved efficiencyLoss into TF plans
%      1999-01-05 (DaB)	 Added FSAN noise models
%      1999-01-07 (DaB)  Added start and stop values for active bands
%      1999-01-07 (DaB)  Added ADSL lite models+ higher HAMbands 
%      1999-01-11 (ToNo) Renamed PBOs
%      1999-01-14 (ToNo) Corrected comments
%      1999-01-15 (Mke)  Added TFplans
%      1999-01-19 (Mke)  Updated TFplans
%      1999-02-08 (DaB)  changed format to enable function calls 
%      1999-02-08 (DaB)  Added new model for ISDN PRA
%      1999-02-24 (DaB)  Updated some models to be inline with TD20 ETSI Villach 1999
%      1999-02-25 (ToNo) Generlized list (tfplist) handling
%      1999-02-26 (ToNo) Fixed Hamband below 200e3
%      1999-03-01 (DaB)  Rewritten HAM band defintion
%      1999-03-02 (DaB)  Added new noise model VDSL SDSL
%      1999-03-03 (DaB)  Fixed error in model E new ref TD17 rev 12
%      1999-03-05 (ToNo) Renamed and modified hamband to ITU-HAMBAND
%      1999-03-15 (DaB)  Set effiency loss to zero default
%      1999-03-30 (DaB)  Out-of-band level for VDSL PSD set to -120 dBm/Hz
%% ===========================================================================

% =============================== Time and Frequency planning
% Format 1 is: [ band1start band1stop energy; band2start band2stop energy]
% Format 2 is: [ frequency1 energy; frequency2 energy]


% HAM bands
tmp_tfplan.name='ITU-HAMBAND'; 
tmp_tfplan.downstream='calcPSD([ 3e3 0 200e3 0 1.81e6 0 1.81e6 -80 2e6 -80 2e6 0 3.5e6 0 3.5e6 -80 4e6 -80 4e6 0 7e6 0 7e6 -80 7.1e6 -80 7.1e6 0 10.1e6 0 10.1e6 -80 10.15e6 -80 10.15e6 0 14e6 0 14e6 -80 14.35e6 -80 14.35e6 0 18.068e6 0 18.068e6 -80 18.168e6 -80 18.168e6 0 21e6 0 21e6 -80 21.45e6 -80 21.45e6 0 24.89e6 0 24.89e6 -80 24.99e6 -80 24.99e6 0 28e6 0 28e6 -80 29.7e6 -80 29.7e6 0],''Linear'')';
tmp_tfplan.upstream=tmp_tfplan.downstream;
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='None';	% Power back-off method (-=not applicable)
tmp_tfplan.PBOparam=0;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[0 0];
tmp_tfplan.active.downstream=[0 0];
tfplist(1)=tmp_tfplan;

% VDSL TDD sym 1:1
tmp_tfplan.name='VDSL-TDD-sym-1:1';
tmp_tfplan.downstream ='calcPSD([.3e6 -120 .3e6 -60 11.04e6 -60 11.04e6 -120],''Linear'')'; 
tmp_tfplan.upstream=tmp_tfplan.downstream;
tmp_tfplan.timeDivision.up=.5;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=.5;
tmp_tfplan.PBOmethod='RefLen';	% Power back-off method (rl=reference length)
tmp_tfplan.PBOparam=1500;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[0.3e6 11.04e6];
tmp_tfplan.active.downstream=[0.3e6 11.04e6];
tfplist=insertList(tfplist,tmp_tfplan);

% VDSL TDD asym 2:1
tmp_tfplan.name='VDSL-TDD-asym-2:1';
tmp_tfplan.downstream ='calcPSD([.3e6 -120 .3e6 -60 11.04e6 -60 11.04e6 -120],''Linear'')'; 
tmp_tfplan.upstream=tmp_tfplan.downstream;
tmp_tfplan.timeDivision.up=1/3;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=2/3;
tmp_tfplan.PBOmethod='RefLen';	% Power back-off method (rl=reference length)
tmp_tfplan.PBOparam=1500;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[0.3e6 11.04e6];
tmp_tfplan.active.downstream=[0.3e6 11.04e6];
tfplist=insertList(tfplist,tmp_tfplan);

% VDSL TDD asym 4:1
tmp_tfplan.name='VDSL-TDD-asym-4:1';
tmp_tfplan.downstream ='calcPSD([.3e6 -120 .3e6 -60 11.04e6 -60 11.04e6 -120],''Linear'')'; 
tmp_tfplan.upstream=tmp_tfplan.downstream;
tmp_tfplan.timeDivision.up=1/5;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=4/5;
tmp_tfplan.PBOmethod='RefLen';	% Power back-off method (rl=reference length)
tmp_tfplan.PBOparam=1500;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[0.3e6 11.04e6];
tmp_tfplan.active.downstream=[0.3e6 11.04e6];
tfplist=insertList(tfplist,tmp_tfplan);

% VDSL TDD asym 8:1
tmp_tfplan.name='VDSL-TDD-asym-8:1';
tmp_tfplan.downstream ='calcPSD([.3e6 -120 .3e6 -60 11.04e6 -60 11.04e6 -120],''Linear'')'; 
tmp_tfplan.upstream=tmp_tfplan.downstream;
tmp_tfplan.timeDivision.up=1/9;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=8/9;
tmp_tfplan.PBOmethod='RefLen';	% Power back-off method (rl=reference length)
tmp_tfplan.PBOparam=1500;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[0.3e6 11.04e6];
tmp_tfplan.active.downstream=[0.3e6 11.04e6];
tfplist=insertList(tfplist,tmp_tfplan);

% VDSL FDD
tmp_tfplan.name='VDSL-FDD';
tmp_tfplan.downstream ='calcPSD([.3e6 -120 .3e6 -60 3.5e6 -60 3.5e6 -120],''Linear'')'; 
tmp_tfplan.upstream   ='calcPSD([3.5e6 -120 3.5e6 -60 11.04e6 -60 11.04e6 -120],''Linear'')'; 
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='RefFreq';	% Power back-off method (rl=reference length)
tmp_tfplan.PBOparam=5e6;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[3.5e6 11.04e6];
tmp_tfplan.active.downstream=[0.3e6 3.5e6];
tfplist=insertList(tfplist,tmp_tfplan);

% VDSL FDD-Z sym example FTTCab
tmp_tfplan.name='VDSL-FDD-Z-sym-FTTCab';
tmp_tfplan.upstream='calcPSD([200e3 -120 200e3 -60 300e3 -60 300e3 -120 1.61e6 -120 1.61e6 -60 4.0e6 -60 4.0e6 -120 7.10e6 -120 7.10e6 -60 11.04e6 -60 11.04e6 -120],''Linear'')';
tmp_tfplan.downstream='calcPSD([300e3 -120 300e3 -60 1.61e6 -60 1.61e6 -120 4.0e6 -120 4.0e6 -60 7.10e6 -60 7.10e6 -120],''Linear'')'; 
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='RefLen';	% Power back-off method (rl=reference length)
tmp_tfplan.PBOparam=500;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[0.2e6 11.04e6];
tmp_tfplan.active.downstream=[0.2e6 11.04e6];
tfplist=insertList(tfplist,tmp_tfplan);

% VDSL FDD-Z sym to asym example FTTCab
tmp_tfplan.name='VDSL-FDD-Z-s2a-FTTCab';
tmp_tfplan.upstream='calcPSD([200e3 -120 200e3 -60 300e3 -60 300e3 -120 2.3e6 -120 2.3e6 -60 4.35e6 -60 4.35e6 -120 7.10e6 -120 7.10e6 -60 11.04e6 -60 11.04e6 -120],''Linear'')';
tmp_tfplan.downstream='calcPSD([300e3 -120 300e3 -60 2.3e6 -60 2.3e6 -120 4.35e6 -120 4.35e6 -60 7.10e6 -60 7.10e6 -120],''Linear'')'; 
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='RefLen';	% Power back-off method (rl=reference length)
tmp_tfplan.PBOparam=800;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[0.2e6 11.04e6];
tmp_tfplan.active.downstream=[0.2e6 11.04e6];
tfplist=insertList(tfplist,tmp_tfplan);

% VDSL FDD-Z asym example FTTEx
tmp_tfplan.name='VDSL-FDD-Z-asym-FTTEx';
tmp_tfplan.upstream='calcPSD([200e3 -120 200e3 -60 400e3 -60 400e3 -120 1.1e6 -120 1.1e6 -60 2.65e6 -60 2.65e6 -120 7.10e6 -120 7.10e6 -60 7.50e6 -60 7.50e6 -120],''Linear'')';
tmp_tfplan.downstream='calcPSD([400e3 -120 400e3 -60 1.1e6 -60 1.1e6 -120 2.65e6 -120 2.65e6 -60 7.10e6 -60 7.10e6 -120 7.50e6 -120 7.50e6 -60 11.04e6 -60 11.04e6 -120],''Linear'')'; 
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='RefLen';	% Power back-off method (rl=reference length)
tmp_tfplan.PBOparam=1100;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[0.2e6 11.04e6];
tmp_tfplan.active.downstream=[0.2e6 11.04e6];
tfplist=insertList(tfplist,tmp_tfplan);

% VDSL FDD-Z asym example FTTEx PB
tmp_tfplan.name='VDSL-FDD-Z-asym-FTTEx-PB';
tmp_tfplan.upstream='calcPSD([100e3 -120 100e3 -40 300e3 -40 300e3 -120 1.1e6 -120 1.1e6 -60 4.3e6 -60 4.3e6 -120 7.10e6 -120 7.10e6 -60 7.50e6 -60 7.50e6 -120],''Linear'')';
tmp_tfplan.downstream='calcPSD([300e3 -120 300e3 -40 1.1e6 -40 1.1e6 -120 4.3e6 -120 4.3e6 -60 7.10e6 -60 7.10e6 -120 7.50e6 -120 7.50e6 -60 11.04e6 -60 11.04e6 -120],''Linear'')'; 
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='RefLen';	% Power back-off method (rl=reference length)
tmp_tfplan.PBOparam=1500;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[0.1e6 11.04e6];
tmp_tfplan.active.downstream=[0.1e6 11.04e6];
tfplist=insertList(tfplist,tmp_tfplan);

% VDSL FDD-Z sym example FTTEx
tmp_tfplan.name='VDSL-FDD-Z-sym-FTTEx';
tmp_tfplan.upstream='calcPSD([200e3 -120 200e3 -60 400e3 -60 400e3 -120 1.71e6 -120 1.71e6 -60 4.10e6 -60 4.10e6 -120 7.10e6 -120 7.10e6 -60 11.04e6 -60 11.04e6 -120],''Linear'')';
tmp_tfplan.downstream='calcPSD([400e3 -120 400e3 -60 1.71e6 -60 1.71e6 -120 4.10e6 -120 4.10e6 -60 7.10e6 -60 7.10e6 -120],''Linear'')'; 
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='RefLen';	% Power back-off method (rl=reference length)
tmp_tfplan.PBOparam=1100;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[0.2e6 11.04e6];
tmp_tfplan.active.downstream=[0.2e6 11.04e6];
tfplist=insertList(tfplist,tmp_tfplan);

% VDSL FDD-Z sym example FTTEx PB
tmp_tfplan.name='VDSL-FDD-Z-sym-FTTEx-PB';
tmp_tfplan.upstream='calcPSD([100e3 -120 100e3 -40 300e3 -40 300e3 -120 1.1e6 -120 1.1e6 -60 4.10e6 -60 4.10e6 -120 7.10e6 -120 7.10e6 -60 11.04e6 -60 11.04e6 -120],''Linear'')';
tmp_tfplan.downstream='calcPSD([300e3 -120 300e3 -40 1.1e6 -40 1.1e6 -120 4.10e6 -120 4.10e6 -60 7.10e6 -60 7.10e6 -120],''Linear'')'; 
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='RefLen';	% Power back-off method (rl=reference length)
tmp_tfplan.PBOparam=1100;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[0.1e6 11.04e6];
tmp_tfplan.active.downstream=[0.1e6 11.04e6];
tfplist=insertList(tfplist,tmp_tfplan);

% VDSL FDD, Coallision example S1-03NAE-A (ref. ETSI TM6, France nov 24-27 1998, TD20)
tmp_tfplan.name='VDSL-FDD-C-S1-03NAE-A';
tmp_tfplan.upstream='calcPSD([3.80e6 -120 3.80e6 -60 6.75e6 -60 6.75e6 -120],''Linear'')';
tmp_tfplan.downstream='calcPSD([0.31e6 -120 0.31e6 -60 3.06e6 -60 3.06e6 -120],''Linear'')'; 
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='RefFreq';	% Power back-off method (rl=reference length)
tmp_tfplan.PBOparam=1e6;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[0.3e6 11.04e6];
tmp_tfplan.active.downstream=[0.3e6 11.04e6];
tfplist=insertList(tfplist,tmp_tfplan);

% VDSL FDD, Coallision example S2-13NAE-A (ref. ETSI TM6, France nov 24-27 1998, TD20)
tmp_tfplan.name='VDSL-FDD-C-S2-13NAE-A';
tmp_tfplan.upstream='calcPSD([3.80e6 -120 3.80e6 -60 7.69e6 -60 7.69e6 -120],''Linear'')';
tmp_tfplan.downstream='calcPSD([0.30e6 -120 0.30e6 -60 3.22e6 -60 3.22e6 -120],''Linear'')'; 
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='RefFreq';	% Power back-off method (rl=reference length)
tmp_tfplan.PBOparam=1e6;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[0.3e6 11.04e6];
tmp_tfplan.active.downstream=[0.3e6 11.04e6];
tfplist=insertList(tfplist,tmp_tfplan);

%VDSL FDD, Coallision example S3-03NAC-B (ref. ETSI TM6, France nov 24-27 1998, TD20)
tmp_tfplan.name='VDSL-FDD-C-S3-03NAC-B';
tmp_tfplan.upstream='calcPSD([1.10e6 -120 1.10e6 -54 2.07e6 -54 2.07e6 -120],''Linear'')';
tmp_tfplan.downstream='calcPSD([2.50e6 -120 2.50e6 -60 10.76e6 -60 10.76e6 -120 11.80e6 -120 11.80e6 -60 24.44e6 -60 24.44e6 -120],''Linear'')'; 
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='RefFreq';	% Power back-off method (rl=reference length)
tmp_tfplan.PBOparam=1e6;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[0.3e6 24.44e6];
tmp_tfplan.active.downstream=[0.3e6 24.44e6];
tfplist=insertList(tfplist,tmp_tfplan);

% ADSL over POTS Reference  ETSI TD 20 Villach
tmp_tfplan.name='ADSL'; 
tmp_tfplan.downstream='calcPSD([.0001e6 -97.5 .00399e6 -97.5 .004e6 -92.5  .025875e6 -39.5 1.104e6 -39.5 3.093e6 -90 4.545e6 -110 30.e6 -110],''Log-Linear'')';
tmp_tfplan.upstream='calcPSD([.0001e6 -97.5 .00399e6 -97.5 .004e6 -92.5 .025875e6 -37.5 0.138e6 -37.5 0.307e6 -90 1.221e6 -90 1.63e6 -110 30.e6 -110],''Log-Linear'')';
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='None';	% Power back-off method (-=not applicable)
tmp_tfplan.PBOparam=0;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[25.875e3 138e3];
tmp_tfplan.active.downstream=[25.875e3 1.104e6];
tfplist=insertList(tfplist,tmp_tfplan);

% ADSL Lite (G.lite) Reference  ETSI TD 20 Villach
tmp_tfplan.name='ADSL-lite';
tmp_tfplan.downstream='calcPSD([.0001e6 -97.5 .00399e6 -97.5 .004e6 -92.5  .08e6 -72.5 0.138e6 -44.2 0.1381e6 -39.5 0.552e6 -39.5  0.956e6 -65 1.8e6 -65 2.290e6 -90 3.093e6 -90 4.545e6 -110 30.e6 -110],''Log-Linear'')';
tmp_tfplan.upstream='calcPSD([.0001e6 -97.5 .00399e6 -97.5 .004e6 -92.5 .025875e6 -37.5 0.138e6 -37.5 0.307e6 -90 1.221e6 -90 1.63e6 -110 30.e6 -110],''Log-Linear'')';
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='None';	% Power back-off method (-=not applicable)
tmp_tfplan.PBOparam=0;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[25.875e3 138e3];
tmp_tfplan.active.downstream=[138e3 552e3];
tfplist=insertList(tfplist,tmp_tfplan);

% ADSL over ISDN Reference  ETSI TD 20 Villach
tmp_tfplan.name='ADSL-overISDN'; 
tmp_tfplan.downstream='calcPSD([.0001e6 -90 .05e6 -90 .080e6 -81.9 .138e6 -39.5  1.104e6 -39.5 3.093e6 -90 4.545e6 -110 30.e6 -110],''Log-Linear'')';
tmp_tfplan.upstream='calcPSD([.0001e6 -90 .05e6 -90 .08e6 -81.9 .138e6 -37.5 0.276e6 -37.5 0.614e6 -90 1.221e6 -90 1.63e6 -110 30.e6 -110],''Log-Linear'')';
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='None';	% Power back-off method (None = not applicable)
tmp_tfplan.PBOparam=0;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[25.875e3 138e3]; % NEEDS CHECKING!
tmp_tfplan.active.downstream=[25.875e3 1.104e6];
tfplist=insertList(tfplist,tmp_tfplan);

% HDSL 1
tmp_tfplan.name='HDSL-1';
tmp_tfplan.downstream='calcPSD([.0001e6 -41.5 .485e6 -41.5 4.85e6 -121.5 30e6 -121.5],''Log-Linear'')';
tmp_tfplan.upstream=tmp_tfplan.downstream;
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='None';	% Power back-off method (-=not applicable)
tmp_tfplan.PBOparam=0;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[.0001e6 .485e6];
tmp_tfplan.active.downstream=[.0001e6 .485e6];
tfplist=insertList(tfplist,tmp_tfplan);

% HDSL 2 (2B1Q) Reference  ETSI TD 20 Villach
tmp_tfplan.name='HDSL-2';
tmp_tfplan.downstream='calcPSD([.0001e6 -39 .292e6 -39 2.92e6 -119 30e6 -119],''Log-Linear'')';
tmp_tfplan.upstream=tmp_tfplan.downstream;
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='None';	% Power back-off method (-=not applicable)
tmp_tfplan.PBOparam=0;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[0.0001e6 0.292e6];
tmp_tfplan.active.downstream=[0.0001e6 0.292e6];
tfplist=insertList(tfplist,tmp_tfplan);

% HDSL 3
tmp_tfplan.name='HDSL-3';
tmp_tfplan.downstream='calcPSD([.0001e6 -37 .196e6 -37 1.96e6 -117 30e6 -117],''Log-Linear'')';
tmp_tfplan.upstream=tmp_tfplan.downstream;
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='None';	% Power back-off method (-=not applicable)
tmp_tfplan.PBOparam=0;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[1e3 196e3];
tmp_tfplan.active.downstream=[1e3 196e3];
tfplist=insertList(tfplist,tmp_tfplan);

% ISDN 2B1Q Reference  ETSI TD 20 Villach
tmp_tfplan.name='ISDN-2B1Q';
tmp_tfplan.downstream='calcPSD([.0001e6 -30 .05e6 -30 .3e6 -69 .301e6 -79  .5e6 -90 1.4e6 -90 3.637e6 -120 30e6 -120],''Log-Linear'')';
tmp_tfplan.upstream=tmp_tfplan.downstream;
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='None';	% Power back-off method (-=not applicable)
tmp_tfplan.PBOparam=0;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[1e3 40e3];
tmp_tfplan.active.downstream=[1e3 40e3];
tfplist=insertList(tfplist,tmp_tfplan);

% ISDN 4B3T (for DTAG) Reference  ETSI TD 20 Villach
tmp_tfplan.name='ISDN-4B3T';
tmp_tfplan.downstream='calcPSD([.0001e6 -30 .05e6 -30 .3e6 -67 .301e6 -74  1e6 -74 4.043e6 -120 30e6 -120],''Log-Linear'')';
tmp_tfplan.upstream=tmp_tfplan.downstream;
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='None';	% Power back-off method (-=not applicable)
tmp_tfplan.PBOparam=0;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[1e3 50e3];
tmp_tfplan.active.downstream=[1e3 50e3];
tfplist=insertList(tfplist,tmp_tfplan);


% ISDN PRI  Check function modelPSD_isdn_pra for model source
tmp_tfplan.name='ISDN-PRI';
tmp_tfplan.downstream='modelPSD_isdn_pra(ex.param.f)';
tmp_tfplan.upstream=tmp_tfplan.downstream;
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='None';	% Power back-off method (-=not applicable)
tmp_tfplan.PBOparam=0;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[1e3 2.1e6];
tmp_tfplan.active.downstream=[1e3 2.1e6];
tfplist=insertList(tfplist,tmp_tfplan);

%% ===========================================================================
% FSAN noise models
%-------------------

% models Alien crosstalk from a disturber shall be coupled with and NEXT and FEXT functions 
% Reference TD17, TD20 ETSI TM6 Villach 1999  

tmp_tfplan.name='Model A (SDSL)';
tmp_tfplan.downstream='calcPSD([1 -18.2 50e3 -18.2 75e3 -25.4 290e3 -25.4 330e3 -26.1 1.104e6 -26.1 2.50e6 -66.2 4.53e6 -96.5 30e6 -96.5],''Log-Linear'')';
tmp_tfplan.upstream='calcPSD([1 -18.2 50e3 -18.2 75e3 -25.2 275e3 -25.3 400e3 -40.5 600e3 -54.3 1e6 -71.5 2.75e6 -96.5 30e6 -96.5],''Log-Linear'')';
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='None';	% Power back-off method (-=not applicable)
tmp_tfplan.PBOparam=0;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[1 30e6];
tmp_tfplan.active.downstream=[1 30e6];
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan.name='Model B (SDSL)';
tmp_tfplan.downstream='calcPSD([1 -22.2 50e3 -22.2 77e3 -30.2 292e3 -30.3 330e3 -30.8 550e3 -30.8 600e3 -32.6 700e3 -33.6 1.104e6 -33.6 4.53e6 -101 30e6 -101],''Log-Linear'')';
tmp_tfplan.upstream='calcPSD([1 -22.2 50e3 -22.2 71e3 -29.3 145e3 -29.5 175e3 -31.0 274e3 -31.0 400e3 -45.9 600e3 -59.6 1e6 -76.8 2e6 -93.5 3e6 -101 30e6 -101],''Log-Linear'')';
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='None';	% Power back-off method (-=not applicable)
tmp_tfplan.PBOparam=0;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[1 30e6];
tmp_tfplan.active.downstream=[1 30e6];
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan.name='Model C (SDSL)';
tmp_tfplan.downstream='calcPSD([1 -22.2 50e3 -22.2 74e3 -30.2 292e3 -30.3 330e3 -30.8 550e3 -30.8 600e3 -32.6 700e3 -33.6 1.104e6 -33.6 2e6 -62 15e6 -101 30e6 -101],''Log-Linear'')';
tmp_tfplan.upstream='calcPSD([1	-22.2 50e3 -22.2 71e3 -29.3 145e3 -29.5 175e3 -31.0 274e3 -31.0 450e3 -48.8 900e3 -46.6 1.2e6 -48.2 1.5e6 -52.0 1.78e6 -60.3 16e6 -101 30e6 -101],''Log-Linear'')';
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='None';	% Power back-off method (-=not applicable)
tmp_tfplan.PBOparam=0;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[1 30e6];
tmp_tfplan.active.downstream=[1 30e6];
tfplist=insertList(tfplist,tmp_tfplan);


tmp_tfplan.name='Model A (FTTCab VDSL)';
tmp_tfplan.downstream='calcPSD([4e3 -22.2 50e3 -22.2 75e3 -30.6 100e3 -34.2 292e3 -35.3 400e3 -43.7 1.104e6 -52.6 2.5e6 -99.6 3.637e6 -111.3 30e6 -111.5],''Log-Linear'')';
tmp_tfplan.upstream='calcPSD([4e3 -22.2 50e3 -22.2 75e3 -29.3 100e3 -30.8 138e3 -31 150e3 -34.2 166e3 -35.3 292e3 -35.4 400e3 -46.3 900e3 -74.5 1.104e6 -79.6 1.4e6 -82 2.5e6 -99.8 3.2e6 -103.5 4.545e6 -103.9 30e6 -103.9],''Log-Linear'')';
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='None';	% Power back-off method (-=not applicable)
tmp_tfplan.PBOparam=0;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[1 30e6];
tmp_tfplan.active.downstream=[1 30e6];
tfplist=insertList(tfplist,tmp_tfplan);



tmp_tfplan.name='Model B (FTTCab VDSL)';
tmp_tfplan.downstream='calcPSD([4e3 -22.2 50e3 -22.2 75e3 -30.7 100e3 -34.4 135e3 -35.3 139e3 -35.1 292e3 -35.3 400e3 -43.7 552e3 -46.7 956e3 -74.5 1.8e6 -83.3 2e6 -93.1 3.637e6 -111.3 30e6 -111.5],''Log-Linear'')';
tmp_tfplan.upstream='calcPSD([4e3 -22.2 50e3 -22.1 75e3 -29.3 100e3 -30.8 138e3 -31 150e3 -34.2 166e3 -35.3 292e3 -35.4 400e3 -46.3 900e3 -74.5 1.104e6 -79.6 1.4e6 -82 2.5e6 -99.8 3.2e6 -103.5 4.545e6 -103.9 30e6 -103.9],''Log-Linear'')';
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='None';	% Power back-off method (-=not applicable)
tmp_tfplan.PBOparam=0;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[1 30e6];
tmp_tfplan.active.downstream=[1 30e6];
tfplist=insertList(tfplist,tmp_tfplan);


tmp_tfplan.name='Model C (FTTCab VDSL)';
tmp_tfplan.downstream='calcPSD([4e3 -22.2 50e3 -22.2 75e3 -30.6 100e3 -34.2 292e3 -35.3 400e3 -43.6 500e3 -45.4 900e3 -46.5 1.024e6 -46.9 1.4e6 -50.6 1.8e6 -60.6 16.5e6 -103.1 30e6 -109.8],''Log-Linear'')';
tmp_tfplan.upstream='calcPSD([4e3 -22.2 50e3 -22.1 75e3 -29.3 100e3 -30.8 138e3 -31 150e3 -34.2 166e3 -35.3 292e3 -35.4 400e3 -46 500e3 -49.1 900e3 -47.1 1.024e6 -47.3 1.4e6 -50.7 1.8e6 -60.6 16.5e6 -101.7 30e6 -103.7],''Log-Linear'')';
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='None';	% Power back-off method (-=not applicable)
tmp_tfplan.PBOparam=0;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[1 30e6];
tmp_tfplan.active.downstream=[1 30e6];
tfplist=insertList(tfplist,tmp_tfplan);


tmp_tfplan.name='Model D (FTTEx VDSL)';
tmp_tfplan.downstream='calcPSD([4e3 -18.2 50e3 18.2 75e3 -25.1 117e3 -26.6 138e3 -25.4 290e3 -25.4 330e3 -25.8 1.104e6 -26 2.5e6 -66 4.53e6 -96 30e6 -96.4],''Log-Linear'')';
tmp_tfplan.upstream='calcPSD([4e3 -18.2 50e3 -18.1 75e3 -24.2 275e3 -25.4 400e3 -40.6 600e3 -54.3 1e6 -71.6 2.75e6 -95.7 30e6 -96.4],''Log-Linear'')';
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='None';	% Power back-off method (-=not applicable)
tmp_tfplan.PBOparam=0;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[1 30e6];
tmp_tfplan.active.downstream=[1 30e6];
tfplist=insertList(tfplist,tmp_tfplan);


tmp_tfplan.name='Model E (FTTEx VDSL)';
tmp_tfplan.downstream='calcPSD([4e3 -22.2 50e3 -22.2 77e3 -30.9 117e3 -35 140e3 -30.2 292e3 -30.3 330e3 -30.6 550e3 -30.6 600e3 -32.5 700e3 -33.4 1.104e6 -33.5 4.53e6 -100.7 30e6 -101.1],''Log-Linear'')';
tmp_tfplan.upstream='calcPSD([4e3 -22.2 50e3 -22.0 71e3 -27.8 145e3 -30 175e3 -31 274e3 -31 400e3 -46.5 600e3 -60.3 1.0e6 -77.1 1.4e6 -82.2 2.8e6 -100.3 30e6 -101.1],''Log-Linear'')';
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='None';	% Power back-off method (-=not applicable)
tmp_tfplan.PBOparam=0;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[1 30e6];
tmp_tfplan.active.downstream=[1 30e6];
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan.name='Model F (FTTEx VDSL)';
tmp_tfplan.downstream='calcPSD([4e3 -22.2 50e3 -22.2 74e3 -30.3 117e3 -35 140e3 -30.2 292e3 -30.3 330e3 -30.6 550e3 -30.6 600e3 -32.5 700e3 -33.4 1.104e6 -33.5 2.1e6 -64.6 2.45e6 -63.6 16.5e6 -99.1 30e6 -101],''Log-Linear'')';
tmp_tfplan.upstream='calcPSD([4e3 -22.2 50e3 -22.1 75e3 -29.3 100e3 -30.8 138e3 -31 150e3 -34.2 166e3 -35.3 292e3 -35.4 400e3 -46 500e3 -49.1 900e3 -47.1 1.024e6 -47.3 1.4e6 -50.7 1.8e6 -60.6 16.5e6 -101.7 30e6 -103.7],''Log-Linear'')';
tmp_tfplan.timeDivision.up=1;	% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='None';	% Power back-off method (-=not applicable)
tmp_tfplan.PBOparam=0;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;
tmp_tfplan.active.upstream=[1 30e6];
tmp_tfplan.active.downstream=[1 30e6];
tfplist=insertList(tfplist,tmp_tfplan);



